# Simulateur de revenu disponible

Ce package contient le modèle de simulation du revenu développé par la chaire [CREEi](http://www.creei.ca). Le simulateur est disponible sur [pip](https://pypi.org/project/srd/). La [documentation](https://creei-models.github.io/srd/) du modèle devrait être consultée concernant l'installation et l'utilisation du modèle.
